@@ -9,8 +9,6 @@
 
 import math
 
-from PySFML import sf
-
 import pilas
 import utils
 
@@ -39,7 +37,4 @@ from cursordisparo import CursorDisparo
 from piedra import Piedra
 from menu import Menu
 from opcion import Opcion
-
-'''
 from tortuga import Tortuga
-'''
